@@ -91,11 +91,11 @@ class ServerlessClusterFromSnapshot(
         enable_data_api: typing.Optional[builtins.bool] = None,
         parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
         removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        scaling: typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions] = None,
+        scaling: typing.Optional[typing.Union[aws_cdk.aws_rds.ServerlessScalingOptions, typing.Dict[str, typing.Any]]] = None,
         security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
         storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
         subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -153,7 +153,7 @@ class ServerlessClusterFromSnapshot(
         automatically_after: typing.Optional[aws_cdk.Duration] = None,
         endpoint: typing.Optional[aws_cdk.aws_ec2.IInterfaceVpcEndpoint] = None,
         exclude_characters: typing.Optional[builtins.str] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> aws_cdk.aws_secretsmanager.SecretRotation:
         '''(deprecated) Adds the multi user rotation to this cluster.
 
@@ -186,7 +186,7 @@ class ServerlessClusterFromSnapshot(
         automatically_after: typing.Optional[aws_cdk.Duration] = None,
         endpoint: typing.Optional[aws_cdk.aws_ec2.IInterfaceVpcEndpoint] = None,
         exclude_characters: typing.Optional[builtins.str] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> aws_cdk.aws_secretsmanager.SecretRotation:
         '''(deprecated) Adds the single user rotation of the master password to this cluster.
 
@@ -339,11 +339,11 @@ class ServerlessClusterFromSnapshotProps:
         enable_data_api: typing.Optional[builtins.bool] = None,
         parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
         removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
-        scaling: typing.Optional[aws_cdk.aws_rds.ServerlessScalingOptions] = None,
+        scaling: typing.Optional[typing.Union[aws_cdk.aws_rds.ServerlessScalingOptions, typing.Dict[str, typing.Any]]] = None,
         security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
         storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
         subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''(deprecated) Properties to configure an Aurora Serverless Cluster.
 
